@@ -133,9 +133,9 @@ class OptionAlwaysShown(OptionInterface):
                 self.widget.clear()
                 if type(supported) == list:
                     for each in supported:
-                        self.widget.addItem(self.combobox_dict[each])
+                        self.widget.addItem(each)
                 else:
-                    self.widget.addItem(self.combobox_dict[supported])
+                    self.widget.addItem(supported)
             elif (type(self.widget) == QComboBox and
                   self.ipp_type == int and
                   self.combobox_map != None):
@@ -310,7 +310,7 @@ class Option(OptionInterface):
 
     def changed(self, widget, *args):
         self.on_change(self)
-    
+
 # ---------------------------------------------------------------------------
 
 class OptionSelectOne(Option):
@@ -319,7 +319,7 @@ class OptionSelectOne(Option):
         Option.__init__(self, name, value, supported, on_change)
 
         self.selector = QComboBox(self)
-        
+
         selected = None
         for nr, choice in enumerate(supported):
             self.selector.addItem(str(choice))
@@ -360,7 +360,7 @@ class OptionSelectMany(Option):
             checkbox.connect(checkbox, SIGNAL("stateChanged(int)"), self.changed)
             self.checkboxes.append(checkbox)
         self.selector = widget
-            
+
     def get_current_value(self):
         return[s for s, chk in zip(self.supported, self.checkboxes)
                if chk.isChecked()]
